//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#ifndef _LFC1_CONFIG_CONFIG_HPP_
#define _LFC1_CONFIG_CONFIG_HPP_

#include <string>
#include <boost/property_tree/ptree.hpp>

#include "lfc1/config/configexp.hpp"

namespace lfc1 { namespace config {

///
///	@ingroup LFC1_CONFIG
///
///	@brief This function obtains the name of a configuration file based on the name of a file.
///
///	If the given executable file name is of the form "somepath/bin*/exename[.ext]", the resulting
///	configuration file name is "somepath/config/exename.xml".  If the given executable file name is of the
///	form "somepath/exename[.ext]", the resulting configuration file name is "somepath/exename.xml".
///
///	@param[in]	arFileName	The name of a file.
///	@param[in]	avAsIs		Indicates whether the file name is used as the name of the configuration file
///							(true) or the name of the executable file from which the configuration file name
///							is going to be derived from (false).
///
///	@return The name of the configuration file.
///
LFC1_CONFIG_API std::string gvGetConfigFileName(const std::string& arFileName, bool avAsIs = false);

///
///	@ingroup LFC1_CONFIG
///
///	@brief XML parses the configuration file.
///
///	@param[in]	arConfigFileName	The name of the configuration file to parse.
///
LFC1_CONFIG_API void gvParseConfigFile(const std::string& arConfigFileName);

///
///	@ingroup LFC1_CONFIG
///
///	@brief Obtains a reference to the configuration file.
///
///	@return A reference to the configuration file.
///
LFC1_CONFIG_API boost::property_tree::ptree& grGetConfigFile();

} /* namespace config */ } /* namespace lfc1 */

#endif // _LFC1_CONFIG_CONFIG_HPP_

//============================================================================================================
//	End of Code
//============================================================================================================
